%global __requires_exclude GLIBC_PRIVATE

#one of valgrind internal library is not linked to libc. Not sure if it should be fixed or not (since all test don't pass anyway), so disable check for now
%define _disable_ld_no_undefined 1

# disable debug package, it can prevent valgrind for working properly
#define debug_package   %{nil}

# (blino) FIXME: reenable qt4 as soon as availble in cauldron
%bcond_with	qt4

Summary:	Tool for finding memory management bugs in programs
Name:		valgrind
Version:	3.10.1
Release:	%mkrel 2
License:	GPLv2+
Group:	Development/Tools
URL:		http://valgrind.org/
ExclusiveArch: %{ix86} x86_64 ppc ppc64 ppc64le s390x armv7hl aarch64
Obsoletes:	valgrind-plugins
Requires: glibc >= 2.20

# Only arches that are supported upstream as multilib and that fedora
# has multilib builds for should set build_multilib 1.
%ifarch x86_64
%global build_multilib 1
%else
%global build_multilib 0
%endif

%global build_openmpi 0

# Don't run dwz or generate minisymtab, valgrind doesn't handle compressed
# DWARF very well and it might read its own vgpreload libraries. Generating
# minisymtabs doesn't really work for the staticly linked tools.
%define _find_debuginfo_dwz_opts %{nil}
%undefine _include_minidebuginfo

Source0: http://www.valgrind.org/downloads/valgrind-%{version}.tar.xz

# From Fedora:

# Needs investigation and pushing upstream
Patch1: valgrind-3.9.0-cachegrind-improvements.patch

# KDE#211352 - helgrind races in helgrind's own mythread_wrapper
Patch2: valgrind-3.9.0-helgrind-race-supp.patch

# undef st_atime, st_mtime and st_ctime. Unknown why this is (still?) needed.
Patch3: valgrind-3.9.0-stat_h.patch

# Make ld.so supressions slightly less specific.
Patch4: valgrind-3.9.0-ldso-supp.patch

# KDE#342795 Internal glibc __GI_mempcpy call should be intercepted
Patch5: valgrind-3.10.1-mempcpy.patch


#END OF FEDORA PATCHES

BuildRequires:	glibc-static-devel
BuildRequires:	gdb
BuildRequires:	libgomp-devel 
BuildRequires:	boost-devel
%if %{with qt4}
BuildRequires:	qt4-devel
%endif
Recommends:	gdb

%if %{build_openmpi}
BuildRequires: openmpi-devel >= 1.3.3
%endif

%description
When a program is run under Valgrind's supervision, all reads and
writes of memory are checked, and calls to malloc/new/free/delete are
intercepted. As a result, Valgrind can detect problems such as:

    * Use of uninitialised memory
    * Reading/writing memory after it has been free'd
    * Reading/writing off the end of malloc'd blocks
    * Reading/writing inappropriate areas on the stack
    * Memory leaks -- where pointers to malloc'd blocks are lost forever
    * Passing of uninitialised and/or unaddressible memory to system calls
    * Mismatched use of malloc/new/new [] vs free/delete/delete []

#--------------------------------------------------------------------

%package	devel
Summary:	%{summary}
Group:		%{group}
Conflicts:	%{name} < 3.6.1-3

%description	devel
Development files required to develop software using valgrind.

#--------------------------------------------------------------------

%package openmpi
Summary: OpenMPI support for valgrind
Group: Development/Tools
Requires: %{?scl_prefix}valgrind = %{version}-%{release}

%description openmpi
A wrapper library for debugging OpenMPI parallel programs with valgrind.
See the section on Debugging MPI Parallel Programs with Valgrind in the
Valgrind User Manual for details.
#--------------------------------------------------------------------
 
%prep
#setup -q
%setup -q -n %{name}-%{version}
%apply_patches

%build
# Convert the library paths with /lib or /lib64 in the suppressions to those
# with /usr/lib or /usr/lib64 due to the /usrmove .
perl -pi -e 's!obj:/lib!obj:/usr/lib!g' *.supp *.supp.in

# (From Fedora):
# Filter out some flags that cause lots of valgrind test failures.
# Also filter away -O2, valgrind adds it wherever suitable, but
# not for tests which should be -O0, as they aren't meant to be
# compiled with -O2 unless explicitely requested. Same for any -mcpu flag.
# Ideally we will change this to only be done for the non-primary build
# and the test suite.
OPTFLAGS="`echo " %{optflags} " | sed 's/ -m\(64\|3[21]\) / /g;s/ -fexceptions / /g;s/ -fstack-protector / / g;s/ -Wp,-D_FORTIFY_SOURCE=2 / /g;s/ -O2 / /g;s/ -mcpu=\([a-z0-9]\+\) / /g;s/^ //;s/ $//'`"
%configure2_5x CC="$CC" CFLAGS="$OPTFLAGS" CXXFLAGS="$OPTFLAGS" \
  GDB=%{_bindir}/gdb

%make

# Ensure there are no unexpected file descriptors open,
# the testsuite otherwise fails.
cat > close_fds.c <<EOF
#include <stdlib.h>
#include <unistd.h>
int main (int argc, char *const argv[])
{
  int i, j = sysconf (_SC_OPEN_MAX);
  if (j < 0)
    exit (1);
  for (i = 3; i < j; ++i)
    close (i);
  execvp (argv[1], argv + 1);
  exit (1);
}
EOF
gcc $RPM_OPT_FLAGS -o close_fds close_fds.c

%install
rm -rf %buildroot
# Don't strip (prevent valgrind from working properly, as explained in README_PACKAGERS)
export DONT_STRIP=1

# FIXME exporting DONT_STRIP=1 is causing some weird behavior with debug_package
# and causing it to not set DISABLE_DEBUG=1
export DISABLE_DEBUG=1

%makeinstall



%files
%doc README* AUTHORS FAQ.txt NEWS
%{_bindir}/*
%{_libdir}/%{name}
%{_mandir}/man1/*.1*

%files devel
%dir %{_includedir}/valgrind
%{_includedir}/valgrind/*
%{_libdir}/pkgconfig/%{name}.pc

%if %{build_openmpi}
%files openmpi
%defattr(-,root,root)
%dir %{_libdir}/valgrind
%{_libdir}/valgrind/libmpiwrap*.so
%endif



%changelog
* Wed Feb 18 2015 bb <bb> 3.10.1-2pclos2015
- rebuild for missing rpm

* Sat Feb 14 2015 bb <bb> 3.10.1-1pclos2015
- sync to fedora and mga
